;+
; NAME: eis_status_sts1_data_dumper.pro
;
; PURPOSE: To convert EIS status 1 parameters from telemetered values
;          to engineering values
;      
; CATEGORY:
;
; CALLING SEQUENCE: 
;
; INPUTS: 
;
; KEYWORD PARAMETERS: None
;
; OUTPUTS: 
;
; CALLS:
;
; COMMON BLOCKS: None
;
; PROCEDURE:
;
; RESTRICTIONS: Uses SolarSoft
;
; MODIFICATION HISTORY:
;	03/June/2006 v1.0 mcrw wrote
;       15/Nov/2006  v1.1 mcrw minor corrections
;
;-------------------------------------------------------------------------------------------------

; units = ['Amps', 'Volts', 'DegC', 'count']
; formats = {amps: '(F7.3)', volts: '(F7.2)'}
; {name: 'ICU_P2I5', bin_table: 2, row: 1, converter: 'eis_convert_icu_current_p2p5v', description: '', unit: 'Amps'}
; {name: 'ICU_P5I',  bin_table: 2, row: 2, converter: 'eis_convert_icu_current_p5v', format = '(F7.2)'}

; {name: 'ICU_P2I5', minv: 0.0, maxv: 0.0, avgv: 0.0}

; {currents: [{name: 'ICU_P2I5', minv: 0.0, maxv: 0.0, avgv: 0.0}, {name: 'ICU_P5I', minv: 0.0, maxv: 0.0, avgv: 0.0}], voltages:[{name: 'ICU_P2V5', minv: 0.0, maxv: 0.0, avgv: 0.0}]}

;pro eis_status_sts1_data_dumper::record, section, pname, minv, maxv, avgv
;  if n_elements(avgv) eq 0 then begin
;     print, section, ' ', pname, minv, maxv
;  endif else begin
;     print, section, ' ', pname, minv, maxv, avgv
;
;;     print, self.parameters['icu_voltages']
;
;;;;     print, 'keys = ', self.parameters.Keys()
;
; ;    foo = self.parameters[section]
; ;    help,foo
;                                ;    print, 'foo keys = ', foo.Keys()
;     parameters = self.parameters
;     print, 'parameters = ', parameters
;     section_hash = parameters[section]
;     ;print, 'boo keys = ', boo.Keys()
;     print, 'section_hash = ', section_hash
;
;     pname_hash = section_hash[pname]
;     print, 'pname_hash = ', pname_hash
;     
;     h = hash('min', minv, 'max', maxv, 'avg', avgv)
;;     hh = hash(pname, h)
;;     self.parameters[section] = hh
;;     hhh = self.parameters[section]
;;     hhhh = hhh[pname]
;;     print, 'hhhh = ', hhhh['min']
;
;     pname_hash = h
;     section_hash[pname] = pname_hash
;     parameters[section] = section_hash
;     self.parameters = parameters
;;     self.parameters[section, pname] = h
;     print, 'UIFBHIuKJLKSFJJFDJF'
;;     stop
;  endelse
;end

; files - string array of filenames in time order
; output - string pathname to where to write ps files
;
pro eis_status_sts1_data_dumper::check_icu_currents, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_currents'
  
  print, '        icu_currents'

  title_str = 'ICU currents (amps)             min            max                avg'

  self->retrieve, 'icu_currents', 'ICU_P2I5',  minv0, maxv0, avgv0
  self->retrieve, 'icu_currents', 'ICU_P5I',   minv1, maxv1, avgv1
  self->retrieve, 'icu_currents', 'ICU_P15I',  minv2, maxv2, avgv2
  self->retrieve, 'icu_currents', 'ICU_N15I',  minv3, maxv3, avgv3
  self->retrieve, 'icu_currents', 'MBUS_28I',  minv4, maxv4, avgv4

  p2v5_str = '+2.5v                 ' + eis_num2str(minv0, type='amps') + eis_num2str(maxv0, type='amps') + eis_num2Str(avgv0, type='amps')
  p5v_str  = '+5v                   ' + eis_num2str(minv1, type='amps') + eis_num2str(maxv1, type='amps') + eis_num2Str(avgv1, type='amps')
  p15v_str = '+15v                  ' + eis_num2str(minv2, type='amps') + eis_num2str(maxv2, type='amps') + eis_num2Str(avgv2, type='amps')
  n15v_str = '-15v                  ' + eis_num2str(minv3, type='amps') + eis_num2str(maxv3, type='amps') + eis_num2Str(avgv3, type='amps')
  mbus_str = 'mbus +28v             ' + eis_num2str(minv4, type='amps') + eis_num2str(maxv4, type='amps') + eis_num2Str(avgv4, type='amps')

  printf, lu, title_str
  printf, lu, p2v5_str
  printf, lu, p5v_str
  printf, lu, p15v_str
  printf, lu, n15v_str
  printf, lu, mbus_str
  printf, lu
end

pro eis_status_sts1_data_dumper::check_icu_voltages, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_voltages'
  
  print, '        icu_voltages'

  title_str = 'ICU voltages (volts)            min            max                avg'

  printf, lu, title_str
  
  self->retrieve, 'icu_voltages', 'ICU_P2V5',  minv0, maxv0, avgv0
  self->retrieve, 'icu_voltages', 'ICU_P5V',   minv1, maxv1, avgv1
  self->retrieve, 'icu_voltages', 'ICU_P15V',  minv2, maxv2, avgv2
  self->retrieve, 'icu_voltages', 'ICU_N15V',  minv3, maxv3, avgv3
  self->retrieve, 'icu_voltages', 'MBUS_28V',  minv4, maxv4, avgv4

;  p2v5_str = eis_min_max_str('+2.5v                 ', 'volts', 'eis_convert_icu_voltage_p2p5v',   minv,  maxv)
  p2v5_str = '+2.5v                 ' + eis_num2str(minv0, type='volts') + eis_num2str(maxv0, type='volts')
  p5v_str  = '+5v                   ' + eis_num2str(minv1, type='volts') + eis_num2str(maxv1, type='volts') + eis_num2str(avgv1, type='volts')
  p15v_str = '+15v                  ' + eis_num2str(minv2, type='volts') + eis_num2str(maxv2, type='volts') + eis_num2str(avgv2, type='volts')
  n15v_str = '-15v                  ' + eis_num2str(minv3, type='volts') + eis_num2str(maxv3, type='volts') + eis_num2str(avgv3, type='volts')
  mbus_str = 'mbus +28v             ' + eis_num2str(minv4, type='volts') + eis_num2str(maxv4, type='volts') + eis_num2str(avgv4, type='volts')

  printf, lu, p2v5_str + '            ' + strtrim(string(avgv0,format='(F7.2)'), 0)
  printf, lu, p5v_str
  printf, lu, p15v_str
  printf, lu, n15v_str
  printf, lu, mbus_str
  printf, lu
  
end

pro eis_status_sts1_data_dumper::check_icu_temperatures, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_temperatures'
  
  print, '        icu_temperatures'

  title_str = 'ICU temperatures (C)            min            max                avg'

  minv = 0.
  maxv = 0.
  avgv = 0.

  printf, lu, title_str
  
  self->retrieve, 'icu_temperatures', 'ICU_PROC_TEMP', minv0, maxv0, avgv0
  self->retrieve, 'icu_temperatures', 'CCDA_TEMP',     minv1, maxv1, avgv1
  self->retrieve, 'icu_temperatures', 'CCDB_TEMP',     minv2, maxv2, avgv2

  p0_str = 'Icu proc              ' + eis_num2str(minv0, type='degC') + eis_num2str(maxv0, type='degC') + eis_num2Str(avgv0, type='degC')
  p1_str = 'CCD-A                 ' + eis_num2str(minv1, type='degC') + eis_num2str(maxv1, type='degC') + eis_num2Str(avgv1, type='degC')
  p2_str = 'CCD-B                 ' + eis_num2str(minv2, type='degC') + eis_num2str(maxv2, type='degC') + eis_num2Str(avgv2, type='degC')

  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu
  
end

pro eis_status_sts1_data_dumper::check_icu_misc_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_misc_parameters'
  
  print, '        icu_misc_parameters'
  
  title_str = 'ICU misc parameters             min            max'

  minv = 0.
  maxv = 0.
  avgv = 0.

  printf, lu, title_str
  
  self->retrieve, 'icu_misc_parameters', 'ICU_SW_ID',     minv0, maxv0, avgv
  self->retrieve, 'icu_misc_parameters', 'PORT_READ',     minv1, maxv1, avgv
  self->retrieve, 'icu_misc_parameters', 'LAST_BC1_R',    minv2, maxv2, avgv
  self->retrieve, 'icu_misc_parameters', 'LAST_BC2_R',    minv3, maxv3, avgv
  self->retrieve, 'icu_misc_parameters', 'LAST_BC3_R',    minv4, maxv4, avgv
  self->retrieve, 'icu_misc_parameters', 'LAST_CMD_L_R',  minv5, maxv5, avgv
  self->retrieve, 'icu_misc_parameters', 'HC_TARGET_T',   minv6, maxv6, avgv
  self->retrieve, 'icu_misc_parameters', 'HC_DUTY_CYCLE', minv7, maxv7, avgv

  p0_str = 'Icu software id       ' + eis_num2str(minv0, type='hex2') + eis_num2str(maxv0, type='hex2')
  p1_str = 'Port read             ' + eis_num2str(minv1, type='hex2') + eis_num2str(maxv1, type='hex2')
  p2_str = 'Last BC1              ' + eis_num2str(minv2, type='hex2') + eis_num2str(maxv2, type='hex2')
  p3_str = 'Last BC2              ' + eis_num2str(minv3, type='hex2') + eis_num2str(maxv3, type='hex2')
  p4_str = 'Last BC3              ' + eis_num2str(minv4, type='hex2') + eis_num2str(maxv4, type='hex2')
  p5_str = 'Last cmd length       ' + eis_num2str(minv5, type='hex2') + eis_num2str(maxv5, type='hex2')
  p6_str = 'HC target temp        ' + eis_num2str(minv6, type='degC') + eis_num2str(maxv6, type='degC')
  p7_str = 'HC duty cycle         ' + eis_num2str(minv7, type='hex2') + eis_num2str(maxv7, type='hex2')

  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu, p7_str
  printf, lu

end

pro eis_status_sts1_data_dumper::check_icu_status_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_status_parameters'
  
  print, '        icu_status_parameters'
  
  title_str = 'ICU status parameters           min            max'

  minv = 0.
  maxv = 0.
  avgv = 0.

  printf, lu, title_str


  self->retrieve, 'icu_status_parameters', 'EIS_MODE',              minp0,  maxp0,  avgv
  self->retrieve, 'icu_status_parameters', 'CCD_BUF_TEST_STAT',     minp1,  maxp1,  avgv
  self->retrieve, 'icu_status_parameters', 'ET_STAT',               minp2,  maxp2,  avgv
  self->retrieve, 'icu_status_parameters', 'CMD_BUF_STAT',          minp3,  maxp3,  avgv
  self->retrieve, 'icu_status_parameters', 'XRT_FF_STAT',           minp4,  maxp4,  avgv
  self->retrieve, 'icu_status_parameters', 'EIS_FF_STAT',           minp5,  maxp5,  avgv
  self->retrieve, 'icu_status_parameters', 'HM_MON_STAT',           minp6,  maxp6,  avgv
  self->retrieve, 'icu_status_parameters', 'AEC_STAT',              minp7,  maxp7,  avgv
  self->retrieve, 'icu_status_parameters', 'MEM_DMP_STAT',          minp8,  maxp8,  avgv
  self->retrieve, 'icu_status_parameters', 'SEQ_STAT',              minp9,  maxp9,  avgv
  self->retrieve, 'icu_status_parameters', 'MODE_EN_STAT',          minp10, maxp10, avgv
  self->retrieve, 'icu_status_parameters', 'XRT_FF_REC',            minp11, maxp11, avgv
  self->retrieve, 'icu_status_parameters', 'XRT_X_COR',             minp12, maxp12, avgv
  self->retrieve, 'icu_status_parameters', 'XRT_Y_COR',             minp13, maxp13, avgv
  self->retrieve, 'icu_status_parameters', 'MD_BUF_STAT',           minp14, maxp14, avgv
  self->retrieve, 'icu_status_parameters', 'ICU_VF',                minp15, maxp15, avgv
  self->retrieve, 'icu_status_parameters', 'PSU_VF',                minp16, maxp16, avgv
  self->retrieve, 'icu_status_parameters', 'CAM_VF',                minp17, maxp17, avgv
  self->retrieve, 'icu_status_parameters', 'MHC_VF',                minp18, maxp18, avgv
  self->retrieve, 'icu_status_parameters', 'ASRC_STAT',             minp19, maxp19, avgv
  self->retrieve, 'icu_status_parameters', 'MHC_LOAD_STAT',         minp20, maxp20, avgv
  self->retrieve, 'icu_status_parameters', 'HC_STAT',               minp21, maxp21, avgv
  self->retrieve, 'icu_status_parameters', 'EEPROM_STAT1',          minp22, maxp22, avgv
  self->retrieve, 'icu_status_parameters', 'EEPROM_STAT2',          minp23, maxp23, avgv
  self->retrieve, 'icu_status_parameters', 'EEPROM_COPY_REQ_STAT',  minp24, maxp24, avgv
  self->retrieve, 'icu_status_parameters', 'EEPROM_COPY_PROG_STAT', minp25, maxp25, avgv
  self->retrieve, 'icu_status_parameters', 'CAM_MHC_PWR_ON',        minp26, maxp26, avgv

  p0_str  = 'EIS mode              ' + eis_num2str(minp0,  type='count') + eis_num2str(maxp0,  type='count')
  p1_str  = 'CCD buf test stat     ' + eis_num2str(minp1,  type='count') + eis_num2str(maxp1,  type='count')
  p2_str  = 'ET stat               ' + eis_num2str(minp2,  type='count') + eis_num2str(maxp2,  type='count')
  p3_str  = 'Cmd buffer stat       ' + eis_num2str(minp3,  type='count') + eis_num2str(maxp3,  type='count')
  p4_str  = 'XRT flare flag stat   ' + eis_num2str(minp4,  type='count') + eis_num2str(maxp4,  type='count')
  p5_str  = 'EIS flare flag stat   ' + eis_num2str(minp5,  type='count') + eis_num2str(maxp5,  type='count')
  p6_str  = 'Health monitor stat   ' + eis_num2str(minp6,  type='count') + eis_num2str(maxp6,  type='count')
  p7_str  = 'AEC stat              ' + eis_num2str(minp7,  type='count') + eis_num2str(maxp7,  type='count')
  p8_str  = 'Memory dump stat      ' + eis_num2str(minp8,  type='count') + eis_num2str(maxp8,  type='count')
  p9_str  = 'Seq stat              ' + eis_num2str(minp9,  type='count') + eis_num2str(maxp9,  type='count')
  p10_str = 'Mode enable stat      ' + eis_num2str(minp10, type='count') + eis_num2str(maxp10, type='count')
  p11_str = 'XRT flare flag rec    ' + eis_num2str(minp11, type='count') + eis_num2str(maxp11, type='count')
  p12_str = 'XRT flare x pos       ' + eis_num2str(minp12, type='count') + eis_num2str(maxp12, type='count')
  p13_str = 'XRT flare y pos       ' + eis_num2str(minp13, type='count') + eis_num2str(maxp13, type='count')
  p14_str = 'Md buffer stat        ' + eis_num2str(minp14, type='count') + eis_num2str(maxp14, type='count')
  p15_str = 'ICU vf                ' + eis_num2str(minp15, type='count') + eis_num2str(maxp15, type='count')
  p16_str = 'PSU vf                ' + eis_num2str(minp16, type='count') + eis_num2str(maxp16, type='count')
  p17_str = 'CAM vf                ' + eis_num2str(minp17, type='count') + eis_num2str(maxp17, type='count')
  p18_str = 'MHC vf                ' + eis_num2str(minp18, type='count') + eis_num2str(maxp18, type='count')
  p19_str = 'ASRC stat             ' + eis_num2str(minp19, type='count') + eis_num2str(maxp19, type='count')
  p20_str = 'MHC load stat         ' + eis_num2str(minp20, type='count') + eis_num2str(maxp20, type='count')
  p21_str = 'HC stat               ' + eis_num2str(minp21, type='count') + eis_num2str(maxp21, type='count')
  p22_str = 'Eeprom stat 1         ' + eis_num2str(minp22, type='count') + eis_num2str(maxp22, type='count')
  p23_str = 'Eeprom stat 2         ' + eis_num2str(minp23, type='count') + eis_num2str(maxp23, type='count')
  p24_str = 'Eeprom copy req stat  ' + eis_num2str(minp24, type='count') + eis_num2str(maxp24, type='count')
  p25_str = 'Eeprom copy prog stat ' + eis_num2str(minp25, type='count') + eis_num2str(maxp25, type='count')
  p26_str = 'MHC power on stat     ' + eis_num2str(minp26, type='count') + eis_num2str(maxp26, type='count')

  printf, lu, p0_str + '	(0 = boot,    1 = standby, 2 = manual,  3 = auto, 4 = bakeout, 5 = emergency)'
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str + '	(1 = running, 2 = stopped, 3 = aborted, 4 = paused)'
  printf, lu, p7_str + '	(1 = running, 2 = stopped, 3 = aborted, 4 = paused)'
  printf, lu, p8_str + '	(1 = running, 2 = stopped, 3 = aborted, 4 = paused)'
  printf, lu, p9_str + '	(1 = running, 2 = stopped, 3 = aborted, 4 = paused)'
  printf, lu, p10_str
  printf, lu, p11_str
  printf, lu, p12_str
  printf, lu, p13_str
  printf, lu, p14_str
  printf, lu, p15_str
  printf, lu, p16_str
  printf, lu, p17_str
  printf, lu, p18_str
  printf, lu, p19_str
  printf, lu, p20_str
  printf, lu, p21_str
  printf, lu, p22_str
  printf, lu, p23_str
  printf, lu, p24_str
  printf, lu, p25_str
  printf, lu, p26_str
  printf, lu

end

pro eis_status_sts1_data_dumper::check_icu_psu_status_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_psu_status_parameters'
  
  print, '        icu_psu_status_parameters'
  
  title_str = 'ICU PSU status parameters       min            max'

  minv = 0.
  maxp = 0.
  avgv = 0.

  printf, lu, title_str

  self->retrieve, 'icu_psu_status_parameters', 'PSU_MARK',           minp1,  maxp1
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CCDB_HTR_EN',    minp2,  maxp2
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CCDA_HTR_EN',    minp3,  maxp3
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CCDB_BHTR_STAT', minp4,  maxp4
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CCDA_BHTR_STAT', minp5,  maxp5
  self->retrieve, 'icu_psu_status_parameters', 'PSU_MHC_HTR_P28V',   minp6,  maxp6
  self->retrieve, 'icu_psu_status_parameters', 'PSU_MHC_MECH_P28V',  minp7,  maxp7
  self->retrieve, 'icu_psu_status_parameters', 'PSU_MHC_ELEC_P28V',  minp8,  maxp8
  self->retrieve, 'icu_psu_status_parameters', 'PSU_MHC_MHTR',       minp9,  maxp9
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_MHTR',       minp10, maxp10
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_P39V',       minp11, maxp11
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_N8V',        minp12, maxp12
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_P7V',        minp13, maxp13
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_P8V',        minp14, maxp14
  self->retrieve, 'icu_psu_status_parameters', 'PSU_CAM_P13V',       minp15, maxp15

  p1_str   = 'PSU mark              ' + eis_num2str(minp1,   type='count') + eis_num2str(maxp1,   type='count')
  p2_str   = 'PSU ccdb htr ena      ' + eis_num2str(minp2,   type='count') + eis_num2str(maxp2,   type='count')
  p3_str   = 'PSU ccda htr ena      ' + eis_num2str(minp3,   type='count') + eis_num2str(maxp3,   type='count')
  p4_str   = 'ccdb bhtr stat        ' + eis_num2str(minp4,   type='count') + eis_num2str(maxp4,   type='count')
  p5_str   = 'PSU ccda bhtr stat    ' + eis_num2str(minp5,   type='count') + eis_num2str(maxp5,   type='count')
  p6_str   = 'PSU MHC htr +28v      ' + eis_num2str(minp6,   type='count') + eis_num2str(maxp6,   type='count')
  p7_str   = 'PSU MHC mech +28v     ' + eis_num2str(minp7,   type='count') + eis_num2str(maxp7,   type='count')
  p8_str   = 'PSU MHC elec +28v     ' + eis_num2str(minp8,   type='count') + eis_num2str(maxp8,   type='count')
  p9_str   = 'PSU MHC mhtr          ' + eis_num2str(minp9,   type='count') + eis_num2str(maxp9,   type='count')
  p10_str  = 'PSU CAM mhtr          ' + eis_num2str(minp10,  type='count') + eis_num2str(maxp10,  type='count')
  p11_str  = 'PSU CAM +39v          ' + eis_num2str(minp11,  type='count') + eis_num2str(maxp11,  type='count')
  p12_str  = 'PSU CAM -8v           ' + eis_num2str(minp12,  type='count') + eis_num2str(maxp12,  type='count')
  p13_str  = 'PSU CAM +7v           ' + eis_num2str(minp13,  type='count') + eis_num2str(maxp13,  type='count')
  p14_str  = 'PSU CAM +8v           ' + eis_num2str(minp14,  type='count') + eis_num2str(maxp14,  type='count')
  p15_str  = 'PSU CAM +13v          ' + eis_num2str(minp15,  type='count') + eis_num2str(maxp15,  type='count')

  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu, p7_str
  printf, lu, p8_str
  printf, lu, p9_str
  printf, lu, p10_str
  printf, lu, p11_str
  printf, lu, p12_str
  printf, lu, p13_str
  printf, lu, p14_str
  printf, lu, p15_str
  printf, lu

end

pro eis_status_sts1_data_dumper::check_icu_hm_status_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_hm_status_parameters'
  
  print, '        icu_hm_status_parameters'
  
  title_str = 'ICU HM status parameters        min            max'

  printf, lu, title_str

  self->retrieve, 'icu_hm_status_parameters', 'HM_ALERT_OOL', minp1, maxp1, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp2, maxp2, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp3, maxp3, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp4, maxp4, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp5, maxp5, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp6, maxp6, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp7, maxp7, argv
  self->retrieve, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp8, maxp8, argv

  p1_str   = 'HM Ool Alert          ' + eis_num2str(minp1,   type='count') + eis_num2str(maxp1,   type='count')
  p2_str   = 'HM PSU Timeout        ' + eis_num2str(minp2,   type='count') + eis_num2str(maxp2,   type='count')
  p3_str   = 'HM CAM Timeout        ' + eis_num2str(minp3,   type='count') + eis_num2str(maxp3,   type='count')
  p4_str   = 'HM MHC Timeout        ' + eis_num2str(minp4,   type='count') + eis_num2str(maxp4,   type='count')
  p5_str   = 'HM PSU Ool            ' + eis_num2str(minp5,   type='count') + eis_num2str(maxp5,   type='count')
  p6_str   = 'HM CAM Ool            ' + eis_num2str(minp6,   type='count') + eis_num2str(maxp6,   type='count')
  p7_str   = 'HM MHC Ool            ' + eis_num2str(minp7,   type='count') + eis_num2str(maxp7,   type='count')
  p8_str   = 'HM Param Id           ' + eis_num2str(minp8,   type='count') + eis_num2str(maxp8,   type='count')

  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu, p7_str
  printf, lu, p8_str
  printf, lu
end

pro eis_status_sts1_data_dumper::check_icu_interface_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_interface_parameters'
  
  print, '        icu_interface_parameters'
  
  title_str = 'ICU interfaces                  min            max'

  printf, lu, title_str

  self->retrieve, 'icu_interface_parameters', 'CMD_IF_STAT1',  minp1,  maxp1
  self->retrieve, 'icu_interface_parameters', 'MD_IF_STAT1',   minp2,  maxp2
  self->retrieve, 'icu_interface_parameters', 'STAT_IF_STAT1', minp3,  maxp3
  self->retrieve, 'icu_interface_parameters', 'WD_IF_STAT1',   minp4,  maxp4
  self->retrieve, 'icu_interface_parameters', 'CMD_IF_STAT2',  minp5,  maxp5
  self->retrieve, 'icu_interface_parameters', 'MD_IF_STAT2',   minp6,  maxp6
  self->retrieve, 'icu_interface_parameters', 'STAT_IF_STAT2', minp7,  maxp7
  self->retrieve, 'icu_interface_parameters', 'WD_IF_STAT2',   minp8,  maxp8
  self->retrieve, 'icu_interface_parameters', 'MHC_422_STAT1', minp9,  maxp9
  self->retrieve, 'icu_interface_parameters', 'ROE_IF_STAT1',  minp10, maxp10
  self->retrieve, 'icu_interface_parameters', 'ROE_IF_STAT2',  minp11, maxp11
  self->retrieve, 'icu_interface_parameters', 'HSL_IF_STAT1',  minp12, maxp12
  self->retrieve, 'icu_interface_parameters', 'HSL_IF_STAT2',  minp13, maxp13
  self->retrieve, 'icu_interface_parameters', 'MHC_422_STAT2', minp14, maxp14

  p1_str  = 'Cmd I/f stat1         ' + eis_num2str(minp1,  type='zcount') + eis_num2str(maxp1,  type='zcount')
  p2_str  = 'Cmd I/f stat2         ' + eis_num2str(minp5,  type='zcount') + eis_num2str(maxp5,  type='zcount')
  p3_str  = 'Md  I/f stat1         ' + eis_num2str(minp2,  type='zcount') + eis_num2str(maxp2,  type='zcount')
  p4_str  = 'Md  I/f stat2         ' + eis_num2str(minp6,  type='zcount') + eis_num2str(maxp6,  type='zcount')
  p5_str  = 'St  I/f stat1         ' + eis_num2str(minp3,  type='zcount') + eis_num2str(maxp3,  type='zcount')
  p6_str  = 'St  I/f stat2         ' + eis_num2str(minp7,  type='zcount') + eis_num2str(maxp7,  type='zcount')
  p7_str  = 'Wd  I/f stat1         ' + eis_num2str(minp4,  type='zcount') + eis_num2str(maxp4,  type='zcount')
  p8_str  = 'Wd  I/f stat2         ' + eis_num2str(minp8,  type='zcount') + eis_num2str(maxp8,  type='zcount')
  p9_str  = 'MHC RS422 I/f stat1   ' + eis_num2str(minp9,  type='zcount') + eis_num2str(maxp9,  type='zcount')
  p10_str = 'MHC RS422 I/f stat2   ' + eis_num2str(minp14, type='zcount') + eis_num2str(maxp14, type='zcount')
  p11_str = 'ROE I/f stat1         ' + eis_num2str(minp10, type='zcount') + eis_num2str(maxp10, type='zcount')
  p12_str = 'ROE I/f stat2         ' + eis_num2str(minp11, type='zcount') + eis_num2str(maxp11, type='zcount')
  p13_str = 'HSL I/f stat1         ' + eis_num2str(minp12, type='zcount') + eis_num2str(maxp12, type='zcount')
  p14_str = 'HSL I/f stat2         ' + eis_num2str(minp13, type='zcount') + eis_num2str(maxp13, type='zcount')

  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu, p7_str
  printf, lu, p8_str
  printf, lu, p9_str
  printf, lu, p10_str
  printf, lu, p11_str
  printf, lu, p12_str
  printf, lu, p13_str + '        (bad ? times)'
  printf, lu, p14_str + '        (bad ? times)'
  printf, lu
end

pro eis_status_sts1_data_dumper::check_icu_error_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_error_parameters'
  
  print, '        icu_error_parameters'

  title_str = 'ICU errors                      min            max'

  printf, lu, title_str

  self->retrieve, 'icu_error_parameters', 'TC_FAILED_EC',      minp1,  maxp1
  self->retrieve, 'icu_error_parameters', 'CMD_IF_ERROR',      minp2,  maxp2
  self->retrieve, 'icu_error_parameters', 'PSU_STAT_ERROR',    minp3,  maxp3
  self->retrieve, 'icu_error_parameters', 'TC_FAILED_CMD_ID',  minp4,  maxp4
  self->retrieve, 'icu_error_parameters', 'ICU_ERROR_F',       minp5,  maxp5
  self->retrieve, 'icu_error_parameters', 'XRT_ERROR',         minp6,  maxp6
  self->retrieve, 'icu_error_parameters', 'HC_DUTY_ERROR',     minp7,  maxp7
  self->retrieve, 'icu_error_parameters', 'HC_PSU_TO',         minp8,  maxp8
  self->retrieve, 'icu_error_parameters', 'MDP_LL_ERROR',      minp9,  maxp9
  self->retrieve, 'icu_error_parameters', 'MHC_CMD_H',         minp10, maxp10
  self->retrieve, 'icu_error_parameters', 'FT_ERROR',          minp11, maxp11
  self->retrieve, 'icu_error_parameters', 'AEC_WIN_ERROR',     minp12, maxp12
  self->retrieve, 'icu_error_parameters', 'AEC_PARMS_ERROR',   minp13, maxp13
  self->retrieve, 'icu_error_parameters', 'AEC_TIME_ERROR',    minp14, maxp14
  self->retrieve, 'icu_error_parameters', 'CAM_IF_ERROR',      minp15, maxp15
  self->retrieve, 'icu_error_parameters', 'SEQ_ABORT_CODE',    minp16, maxp16
  self->retrieve, 'icu_error_parameters', 'CMD_ID_FAILED_INT', minp17, maxp17
  self->retrieve, 'icu_error_parameters', 'MHC_IF_ERROR',      minp18, maxp18
  self->retrieve, 'icu_error_parameters', 'EEPROM_ERROR',      minp19, maxp19
  self->retrieve, 'icu_error_parameters', 'ET_ERROR',          minp20, maxp20
  self->retrieve, 'icu_error_parameters', 'TC_FAILED_PKTC',    minp21, maxp21

  p1_str  = 'ICU error flag        ' + eis_num2str(minp5,  type='count') + eis_num2str(maxp5,  type='count')
  p2_str  = 'Cmd i/f error         ' + eis_num2str(minp2,  type='count') + eis_num2str(maxp2,  type='count')
  p3_str  = 'PSU stat error        ' + eis_num2str(minp3,  type='count') + eis_num2str(maxp3,  type='count')
  p4_str  = 'MDP ll error          ' + eis_num2str(minp9,  type='count') + eis_num2str(maxp9,  type='count')
  p5_str  = 'CAM i/f error         ' + eis_num2str(minp15, type='count') + eis_num2str(maxp15, type='count')
  p6_str  = 'Tc fail pktc          ' + eis_num2str(minp21, type='count') + eis_num2str(maxp21, type='count')
  p7_str  = 'Seq abort             ' + eis_num2str(minp16, type='count') + eis_num2str(maxp16, type='count')
  p8_str  = 'Cmd id int fail       ' + eis_num2str(minp17, type='count') + eis_num2str(maxp17, type='count')
  p9_str  = 'MHC i/f error         ' + eis_num2str(minp18, type='hex2')  + eis_num2str(maxp18, type='hex2')
  p10_str = 'Tc fail ec            ' + eis_num2str(minp1,  type='count') + eis_num2str(maxp1,  type='count')
  p11_str = 'Tc fail cmd           ' + eis_num2str(minp4,  type='count') + eis_num2str(maxp4,  type='count')
  p12_str = 'XRT error             ' + eis_num2str(minp6,  type='count') + eis_num2str(maxp6,  type='count')
  p13_str = 'HC duty error         ' + eis_num2str(minp7,  type='count') + eis_num2str(maxp7,  type='count')
  p14_str = 'HC PSU timeout        ' + eis_num2str(minp8,  type='count') + eis_num2str(maxp8,  type='count')
  p15_str = 'MHC cmd high word     ' + eis_num2str(minp10, type='count') + eis_num2str(maxp10, type='count')
  p16_str = 'FT error              ' + eis_num2str(minp11, type='count') + eis_num2str(maxp11, type='count')
  p17_str = 'AEC window error      ' + eis_num2str(minp12, type='count') + eis_num2str(maxp12, type='count')
  p18_str = 'AEC parameter error   ' + eis_num2str(minp13, type='count') + eis_num2str(maxp13, type='count')
  p19_str = 'AEC time error        ' + eis_num2str(minp14, type='count') + eis_num2str(maxp14, type='count')
  p20_str = 'Eeprom error          ' + eis_num2str(minp19, type='count') + eis_num2str(maxp19, type='count')
  p21_str = 'ET error              ' + eis_num2str(minp20, type='count') + eis_num2str(maxp20, type='count')

  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu, p6_str
  printf, lu, p7_str + '	(1 = ground (MDP) abort, 2 = sequence xsum, 6,7 = linelist error, 8 = shutter abort)'
  printf, lu, p8_str
  printf, lu, p9_str
  printf, lu, p10_str
  printf, lu, p11_str
  printf, lu, p12_str
  printf, lu, p13_str
  printf, lu, p14_str
  printf, lu, p15_str
  printf, lu, p16_str
  printf, lu, p17_str
  printf, lu, p18_str
  printf, lu, p19_str
  printf, lu, p20_str
  printf, lu, p21_str
  printf, lu
end

pro eis_status_sts1_data_dumper::check_icu_counter_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_counter_parameters'
  
  print, '        icu_counter_parameters'
  
  title_str = 'ICU counters                    min            max'
  printf, lu, title_str

  self->retrieve, 'icu_counter_parameters', 'MDP_TIME',       minp0, maxp0
  self->retrieve, 'icu_counter_parameters', 'STATUS_PC',      minp1, maxp1
  self->retrieve, 'icu_counter_parameters', 'TC_REC_PKTC',    minp2, maxp2
  self->retrieve, 'icu_counter_parameters', 'RASTER_RUN_REM', minp3, maxp3
  self->retrieve, 'icu_counter_parameters', 'SEQ_RUN_REM',    minp4, maxp4
  self->retrieve, 'icu_counter_parameters', 'EXP_NUM',        minp5, maxp5

  p1_str  = 'Status PC             ' + eis_num2str(minp1,  type='count') + eis_num2str(maxp1,  type='count')
  p2_str  = 'Tc received count     ' + eis_num2str(minp2,  type='count') + eis_num2str(maxp2,  type='count')
  p3_str  = 'Raster run remaining  ' + eis_num2str(minp3,  type='count') + eis_num2str(maxp3,  type='count')
  p4_str  = 'Seq    run remaining  ' + eis_num2str(minp4,  type='count') + eis_num2str(maxp4,  type='count')
  p5_str  = 'Exposures count       ' + eis_num2str(minp5,  type='count') + eis_num2str(maxp5,  type='count')

  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str
  printf, lu, p4_str
  printf, lu, p5_str
  printf, lu
end

pro eis_status_sts1_data_dumper::check_icu_science_status_parameters, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_science_status_parameters'
  
  print, '        icu_science_status_parameters'
  
  title_str = 'ICU science                     min            max'
  printf, lu, title_str

  self->retrieve, 'icu_science_status_parameters', 'SEQ_I', minp0, maxp0, avg
  self->retrieve, 'icu_science_status_parameters', 'SEQ_P', minp1, maxp1, avg
  self->retrieve, 'icu_science_status_parameters', 'LL_I',  minp2, maxp2, avg
  
  p0_str  = 'Sequence index        ' + eis_num2str(minp0, type='count') + eis_num2str(maxp0, type='count')
  p1_str  = 'Sequence pointer      ' + eis_num2str(minp1, type='count') + eis_num2str(maxp1, type='count')
  p2_str  = 'Linelist index        ' + eis_num2str(minp2, type='count') + eis_num2str(maxp2, type='count')
  p3_str  = 'Sequences run         '

  printf, lu, p0_str
  printf, lu, p1_str
  printf, lu, p2_str
  printf, lu, p3_str + '        ' + 'sequences'
  printf, lu
  
end

pro eis_status_sts1_data_dumper::check_icu_spacecraft, lu
  self->trace, 'eis_status_sts1_data_dumper::check_icu_spacecraft'
  
  print, '        icu_spacecraft'
  
  title_str = 'ICU spacecraft parameters       min            max'
    
  minp = 0.
  maxp = 0.
  avgv = 0.

  printf, lu, title_str
  self->retrieve, 'icu_spacecraft', 'TIME',        minp1, maxp1
  self->retrieve, 'icu_spacecraft', 'SEQ_COUNTER', minp2, maxp2

end

pro eis_status_sts1_data_dumper::title, lu, sdate, edate
  self->trace, 'eis_status_sts1_data_dumper::title'
  
;  time_str  = 'Start: ' + strtrim(string(start_time), 2) + ' End: ' + strtrim(string(end_time), 2)
  printf, lu, 'TITLE'
  printf, lu
end

pro eis_status_sts1_data_dumper::check, lu, sdate, edate
  self->trace, 'eis_status_sts1_data_dumper::check'
  
  self->title,                               lu, sdate, edate
  self->check_icu_voltages,                  lu
  self->check_icu_currents,                  lu
  self->check_icu_temperatures,              lu
  self->check_icu_misc_parameters,           lu
  self->check_icu_status_parameters,         lu
  self->check_icu_psu_status_parameters,     lu
  self->check_icu_hm_status_parameters,      lu
  self->check_icu_interface_parameters,      lu
  self->check_icu_error_parameters,          lu
  self->check_icu_counter_parameters,        lu
  self->check_icu_science_status_parameters, lu
;  self->check_icu_spacecraft,                lu

end
