;+
; NAME: eis_status_sts1_data_dumper.pro
;
; PURPOSE: To convert EIS status 1 parameters from telemetered values
;          to engineering values
;      
; CATEGORY:
;
; CALLING SEQUENCE: 
;
; INPUTS: 
;
; KEYWORD PARAMETERS: None
;
; OUTPUTS: 
;
; CALLS:
;
; COMMON BLOCKS: None
;
; PROCEDURE:
;
; RESTRICTIONS: Uses SolarSoft
;
; MODIFICATION HISTORY:
;	03/June/2006 v1.0 mcrw wrote
;       15/Nov/2006  v1.1 mcrw minor corrections
;
;-------------------------------------------------------------------------------------------------

; units = ['Amps', 'Volts', 'DegC', 'None']
; formats = {amps: '(F7.3)', volts: '(F7.2)'}
; {name: 'ICU_P2I5', bin_table: 2, row: 1, converter: 'eis_convert_icu_current_p2p5v', description: '', unit: 'Amps'}
; {name: 'ICU_P5I',  bin_table: 2, row: 2, converter: 'eis_convert_icu_current_p5v', format = '(F7.2)'}

; {name: 'ICU_P2I5', minv: 0.0, maxv: 0.0, avgv: 0.0}

; {currents: [{name: 'ICU_P2I5', minv: 0.0, maxv: 0.0, avgv: 0.0}, {name: 'ICU_P5I', minv: 0.0, maxv: 0.0, avgv: 0.0}], voltages:[{name: 'ICU_P2V5', minv: 0.0, maxv: 0.0, avgv: 0.0}]}

;pro eis_status_sts1_data_dumper::record, section, pname, minv, maxv, avgv
;  if n_elements(avgv) eq 0 then begin
;     print, section, ' ', pname, minv, maxv
;  endif else begin
;     print, section, ' ', pname, minv, maxv, avgv
;
;;     print, self.parameters['icu_voltages']
;
;;;;     print, 'keys = ', self.parameters.Keys()
;
; ;    foo = self.parameters[section]
; ;    help,foo
;                                ;    print, 'foo keys = ', foo.Keys()
;     parameters = self.parameters
;     print, 'parameters = ', parameters
;     section_hash = parameters[section]
;     ;print, 'boo keys = ', boo.Keys()
;     print, 'section_hash = ', section_hash
;
;     pname_hash = section_hash[pname]
;     print, 'pname_hash = ', pname_hash
;     
;     h = hash('min', minv, 'max', maxv, 'avg', avgv)
;;     hh = hash(pname, h)
;;     self.parameters[section] = hh
;;     hhh = self.parameters[section]
;;     hhhh = hhh[pname]
;;     print, 'hhhh = ', hhhh['min']
;
;     pname_hash = h
;     section_hash[pname] = pname_hash
;     parameters[section] = section_hash
;     self.parameters = parameters
;;     self.parameters[section, pname] = h
;     print, 'UIFBHIuKJLKSFJJFDJF'
;;     stop
;  endelse
;end

; files - string array of filenames in time order
; output - string pathname to where to write ps files
;
pro eis_status_sts1_data_dumper::plot_icu_currents, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_currents'
  
  p2v5 = eis_convert_icu_current_p2p5v  (eis_get_daily_data(files,'ICU_P2I5', 1, 2, mx, mn, base_time, end_time))
  p5v  = eis_convert_icu_current_p5v    (eis_get_daily_data(files,'ICU_P5I',  2, 2, mx, mn))
  p15v = eis_convert_icu_current_p15v   (eis_get_daily_data(files,'ICU_P15I', 3, 2, mx, mn))
  n15v = eis_convert_icu_current_n15v   (eis_get_daily_data(files,'ICU_N15I', 4, 2, mx, mn))
  m28v = eis_convert_icu_current_mbus28v(eis_get_daily_data(files,'MBUS_28I', 5, 2, mx, mn))

  avg = (nan_moment(p2v5))[0]
  minp0 = min(p2v5)
  maxp0 = max(p2v5)
  self->record, 'icu_currents', 'ICU_P2I5', minp0, maxp0, avg

  avg = (nan_moment(p5v))[0]
  minp1 = min(p5v)
  maxp1 = max(p5v)
  self->record, 'icu_currents', 'ICU_P5I', minp1, maxp1, avg

  avg = (nan_moment(p15v))[0]
  minp2 = min(p15v)
  maxp2 = max(p15v)
  self->record, 'icu_currents', 'ICU_P15I', minp2, maxp2, avg

  avg = (nan_moment(n15v))[0]
  minp3 = min(n15v)
  maxp3 = max(n15v)
  self->record, 'icu_currents', 'ICU_N15I', minp3, maxp3, avg

  avg = (nan_moment(m28v))[0]
  minp4 = min(m28v)
  maxp4 = max(m28v)
  self->record, 'icu_currents', 'MBUS_28I', minp4, maxp4, avg

  x = lindgen(n_elements(p2v5)) * 2
  
  cs = 1.6
  
  set_plot, 'ps'
  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/psu_currents.ps'
  ; 1 column by 3 rows
  !p.multi = [0, 1, 3]
  
  utplot, x, p2v5, base_time, timerange = [base_time, end_time], $
;         yrange = [eis_convert_icu_current_p2p5v([minp0]), eis_convert_icu_current_p2p5v([maxp0])], $
         yrange = [minp0 - 1., maxp0 + 1.], $
         xstyle = 2, pstyle = 4, xticks = 100, $
         title = 'PSU +2.5 V Current', ytitle = 'Amps', charsize=cs
  
  utplot, x, p5v, base_time, timerange = [base_time, end_time], $
          yrange = [minp1 - 1., maxp1 + 1.], $
          xstyle = 2, pstyle = 4, $
          title = 'PSU +5 V Current', ytitle = 'Amps', charsize = cs, /ynozero
  
  goto, skip_plots

  utplot, x, p15v, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
         title = 'PSU +15 V Current', ytitle = 'Amps', charsize = cs, /ynozero
  
  utplot, x, n15v, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
         title = 'PSU -15 V Current', ytitle = 'Amps', charsize = cs, /ynozero
  
  utplot, x, m28v, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
         title = 'PSU MBUS 28 V Current', ytitle = 'Amps', charsize = cs, /ynozero
  
skip_plots:
  
  device, /close
  set_plot, 'X'
  !p.multi = 0
  
end

pro eis_status_sts1_data_dumper::plot_icu_voltages, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_voltages'
    
  p2v5 = eis_convert_icu_voltage_p2p5v  (eis_get_daily_data(files, 'ICU_P2V5', 1, 1, maxp1, minp1, base_time, end_time))
  p5v  = eis_convert_icu_voltage_p5v    (eis_get_daily_data(files, 'ICU_P5V',  2, 1, maxp2, minp2))
  p15v = eis_convert_icu_voltage_p15v   (eis_get_daily_data(files, 'ICU_P15V', 3, 1, maxp3, minp3))
  n15v = eis_convert_icu_voltage_n15v   (eis_get_daily_data(files, 'ICU_N15V', 4, 1, maxp4, minp4))
  m28v = eis_convert_icu_voltage_mbus28v(eis_get_daily_data(files, 'MBUS_28V', 5, 1, maxp5, minp5))
  
;    minr = min([minp1, minp2, minp3, minp4, minp5])
;    maxr = max([maxp1, maxp2, maxp3, maxp4, maxp5])

  avg = (nan_moment(p2v5))[0]
  minp1 = eis_convert_icu_voltage_p2p5v([minp1])
  maxp1 = eis_convert_icu_voltage_p2p5v([maxp1])
  self->record, 'icu_voltages', 'ICU_P2V5', minp1, maxp1, avg

  avg = (nan_moment(p5v))[0]
  minp2 = eis_convert_icu_voltage_p5v([minp2])
  maxp2 = eis_convert_icu_voltage_p5v([maxp2])
  self->record, 'icu_voltages', 'ICU_P5V', minp2, maxp2, avg

  avg = (nan_moment(p15v))[0]
  minp3 = eis_convert_icu_voltage_p15v([minp3])
  maxp3 = eis_convert_icu_voltage_p15v([maxp3])
  self->record, 'icu_voltages', 'ICU_P15V', minp3, maxp3, avg

  avg = (nan_moment(n15v))[0]
  minp4 = eis_convert_icu_voltage_n15v([minp4])
  maxp4 = eis_convert_icu_voltage_n15v([maxp4])
  self->record, 'icu_voltages', 'ICU_N15V', minp4, maxp4, avg

  avg = (nan_moment(m28v))[0]
  minp5 = eis_convert_icu_voltage_mbus28v([minp5])
  maxp5 = eis_convert_icu_voltage_mbus28v([maxp5])
  self->record, 'icu_voltages', 'MBUS_28V', minp5, maxp5, avg
  
  x = lindgen(n_elements(p2v5)) * 2
  
  cs = 1.6
  
;    window, /free, xsize=1024
;    !p.multi=0
;    utplot,x,p2v5_arr,base_time,timerange=[base_time,end_time],yrange=[minr-1,maxr+1],xstyle=2,pstyle=4, $
;      title='PSU +2.5 Volts',ytitle='Volts',charsize=cs
;    utplot,x,p5v_arr,base_time,timerange=[base_time,end_time],yrange=[minr-1,maxr+1],xstyle=2,pstyle=4, $
;      title='PSU +5 Volts',ytitle='Volts',charsize=cs
  
  set_plot, 'ps'
  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/psu_voltages.ps'
;;;  !p.multi=[0,1,3]
  !p.multi = [0, 1, 5]
  
  utplot, x, p2v5, base_time, timerange = [base_time, end_time], $
          yrange = [minp1 - 1., maxp1 + 1.], $
          xstyle = 3, pstyle = 4, title = 'PSU +2.5 Volts', ytitle = 'Volts', charsize = cs
  
  utplot, x, p5v, base_time, timerange = [base_time, end_time], $
;         yrange=[eis_convert_icu_voltage_p5v([minp2])-1.,eis_convert_icu_voltage_p5v([maxp2])+1.], $
         yrange = [minp2 - 1., maxp2 + 1.], $
         xstyle = 3, pstyle = 4, title = 'PSU +5 Volts', ytitle = 'Volts', charsize = cs
  
  utplot, x, p15v, base_time, timerange = [base_time, end_time], $
;         yrange=[eis_convert_icu_voltage_p15v([minp3])-1.,eis_convert_icu_voltage_p15v([maxp3])+1.], $
         yrange = [minp3 - 1., maxp3 + 1.], $
         xstyle = 3, pstyle = 4, title = 'PSU +15 Volts', ytitle = 'Volts', charsize = cs
  
  utplot, x, n15v, base_time, timerange = [base_time, end_time], $
;         yrange=[eis_convert_icu_voltage_n15v([minp4])-1.,eis_convert_icu_voltage_n15v([maxp4])+1.], $
         yrange = [minp4 - 1., maxp4 + 1.], $
         xstyle = 3, pstyle = 4, title = 'PSU -15 Volts', ytitle = 'Volts', charsize = cs
  
  utplot, x, m28v, base_time, timerange = [base_time, end_time], $
;         yrange=[eis_convert_icu_voltage_mbus28v([minp5])-1.,eis_convert_icu_voltage_mbus28v([maxp5])+1.], $
         yrange = [minp5 - 1., maxp5 + 1.], $
         xstyle = 3, pstyle = 4, title = 'PSU MBUS 28 Volts', ytitle = 'Volts', charsize = cs
  
  device, /close
  set_plot, 'X'
  !p.multi = 0
  
end

pro eis_status_sts1_data_dumper::plot_icu_temperatures, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_temperatures'
  
  p0 = eis_convert_icu_proc_temperature(eis_get_daily_data(files,'ICU_PROC_TEMP', 3, 3, maxp1, minp1, base_time, end_time))
  p1 = eis_convert_ccda_temperature(eis_get_daily_data    (files,'CCDA_TEMP',     1, 3, maxp2, minp2))
  p2 = eis_convert_ccdb_temperature(eis_get_daily_data    (files,'CCDB_TEMP',     2, 3, maxp3, minp3))

  avg = (nan_moment(p0))[0]
  minp1 = eis_convert_icu_proc_temperature([minp1])
  maxp1 = eis_convert_icu_proc_temperature([maxp1])
  self->record, 'icu_temperatures', 'ICU_PROC_TEMP', minp1, maxp1, avg
  avg = (nan_moment(p1))[0]
  minp2 = eis_convert_ccda_temperature([minp2])
  maxp2 = eis_convert_ccda_temperature([maxp2])
  self->record, 'icu_temperatures', 'CCDA_TEMP', minp2, maxp2, avg
  avg = (nan_moment(p2))[0]
  minp3 = eis_convert_ccdb_temperature([minp3])
  maxp3 = eis_convert_ccdb_temperature([maxp3])
  self->record, 'icu_temperatures', 'CCDB_TEMP', minp3, maxp3, avg


  ccd_yrange_min = min([minp2, minp3])
  ccd_yrange_max = max([maxp2, maxp3])
  
  x = lindgen(n_elements(p0)) * 2
  
  cs = 1.6
  
  set_plot, 'ps'
  device, xoff = 2.5, yoff = 6, xs = 16, ys = 18, file = output + '/icu_temperatures.ps'
  !p.multi = [0, 1, 3]
  
  utplot, x, p0, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
;         yrange = [minp1 - 1., maxp1 + 1.], $
         title = 'ICU PROC TEMP', ytitle = 'Degrees C', charsize = cs
  
  utplot, x, p1, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
         yrange = [ccd_yrange_min - 1., ccd_yrange_max + 1.], $
         title = 'CCD A TEMP', ytitle = 'Degrees C', charsize = cs, /ynozero
  
  utplot, x, p2, base_time, timerange = [base_time, end_time], xstyle = 2, pstyle = 4, $
         yrange = [ccd_yrange_min - 1., ccd_yrange_max + 1.], $
         title = 'CCD B TEMP', ytitle = 'Degrees C', charsize = cs, /ynozero
  
  device, /close
  set_plot, 'X'
  !p.multi = 0
  
end

pro eis_status_sts1_data_dumper::plot_icu_misc_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_misc_parameters'
  
  p0 = eis_get_daily_data(files,'ICU_SW_ID',     1, 4, maxp1, minp1, base_time, end_time)
  p1 = eis_get_daily_data(files,'PORT_READ',     2, 4, maxp2, minp2)
  p2 = eis_get_daily_data(files,'LAST_BC1_R',    3, 4, maxp3, minp3)
  p3 = eis_get_daily_data(files,'LAST_BC2_R',    4, 4, maxp4, minp4)
  p4 = eis_get_daily_data(files,'LAST_BC3_R',    5, 4, maxp5, minp5)
  p5 = eis_get_daily_data(files,'LAST_CMD_L_R',  6, 4, maxp6, minp6)
  p6 = eis_get_daily_data(files,'HC_TARGET_T',   7, 4, maxp7, minp7)
  p7 = eis_get_daily_data(files,'HC_DUTY_CYCLE', 8, 4, maxp8, minp8)

  self->record, 'icu_misc_parameters', 'ICU_SW_ID',     minp1, maxp1
  self->record, 'icu_misc_parameters', 'PORT_READ',     minp2, maxp2
  self->record, 'icu_misc_parameters', 'LAST_BC1_R',    minp3, maxp3
  self->record, 'icu_misc_parameters', 'LAST_BC2_R',    minp4, maxp4
  self->record, 'icu_misc_parameters', 'LAST_BC3_R',    minp5, maxp5
  self->record, 'icu_misc_parameters', 'LAST_CMD_L_R',  minp6, maxp6
  self->record, 'icu_misc_parameters', 'HC_TARGET_T',   minp7, maxp7
  self->record, 'icu_misc_parameters', 'HC_DUTY_CYCLE', minp8, maxp8

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_misc_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time], $
         xstyle=2,pstyle=4,title='ICU SW ID',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='PORT READ',ytitle='None',charsize=cs
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],yrange=[-1,256], $
         xstyle=2,pstyle=4,title='LAST BC1 R',ytitle='None',charsize=cs
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='LAST BC2 R',ytitle='None',charsize=cs
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='LAST BC3 R',ytitle='None',charsize=cs
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='LAST CMD L R',ytitle='None',charsize=cs
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HC TARGET T',ytitle='None',charsize=cs
  
  utplot,x,p7,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HC DUTY CYCLE',ytitle='None',charsize=cs
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_status_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_status_parameters'
  
  p0  = eis_get_daily_data(files,'EIS_MODE',             1,  5, maxp1,  minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'CCD_BUF_TEST_STAT',    2,  5, maxp2,  minp2)
;    p2  = eis_get_daily_data(files,'CCD_BUF_TEST_ERR',     3,  5, maxp3, minp3)
;    p3  = eis_get_daily_data(files,'CCD_BUF_TEST_WR_ERR',  4,  5, maxp3, minp3)
;    p4  = eis_get_daily_data(files,'CCD_BUF_TEST_RD_ERR',  5,  5, maxp3, minp3)
  p5  = eis_get_daily_data(files,'ET_STAT',              3,  5, maxp3,  minp3)
  p6  = eis_get_daily_data(files,'CMD_BUF_STAT',         4,  5, maxp4,  minp4)
  p7  = eis_get_daily_data(files,'XRT_FF_STAT',          5,  5, maxp5,  minp5)
  p8  = eis_get_daily_data(files,'EIS_FF_STAT',          6,  5, maxp6,  minp6)
  p9  = eis_get_daily_data(files,'HM_MON_STAT',          7, 5, maxp7,  minp7)
  p10 = eis_get_daily_data(files,'AEC_STAT',             8, 5, maxp8,  minp8)
  p11 = eis_get_daily_data(files,'MEM_DMP_STAT',         9, 5, maxp9,  minp9)
  p12 = eis_get_daily_data(files,'SEQ_STAT',             10, 5, maxp10, minp10)
  p13 = eis_get_daily_data(files,'MODE_EN_STAT',         11, 5, maxp11, minp11)
  p14 = eis_get_daily_data(files,'XRT_FF_REC',           12, 5, maxp12, minp12)
  p15 = eis_get_daily_data(files,'XRT_X_COR',            13, 5, maxp13, minp13)
  p16 = eis_get_daily_data(files,'XRT_Y_COR',            14, 5, maxp14, minp14)
  p17 = eis_get_daily_data(files,'MD_BUF_STAT',          15, 5, maxp15, minp15)
  p18 = eis_get_daily_data(files,'ICU_VF',               16, 5, maxp16, minp16)
  p19 = eis_get_daily_data(files,'PSU_VF',               17, 5, maxp17, minp17)
  p20 = eis_get_daily_data(files,'CAM_VF',               18, 5, maxp18, minp18)
  p21 = eis_get_daily_data(files,'MHC_VF',               19, 5, maxp19, minp19)
  p22 = eis_get_daily_data(files,'ASRC_STAT',            20, 5, maxp20, minp20)
  p23 = eis_get_daily_data(files,'MHC_LOAD_STAT',        21, 5, maxp21, minp21)
  p24 = eis_get_daily_data(files,'HC_STAT',              22, 5, maxp22, minp22)
  p25 = eis_get_daily_data(files,'EEPROM_STAT1',         23, 5, maxp23, minp23)
  p26 = eis_get_daily_data(files,'EEPROM_STAT2',         24, 5, maxp24, minp24)
  p27 = eis_get_daily_data(files,'EEPROM_COPY_REQ_STAT', 25, 5, maxp25, minp25)
  p28 = eis_get_daily_data(files,'EEPROM_COPY_PROG_STAT',26, 5, maxp26, minp26)
;;;    p29 = eis_get_daily_data(files,'CMS_MHC_PWR_ON',       30, 5, maxp3, minp3)
  p29 = eis_get_daily_data(files,'CAM_MHC_PWR_ON',       27, 5, maxp27, minp27)

  self->record, 'icu_status_parameters', 'EIS_MODE', minp1, maxp1
  self->record, 'icu_status_parameters', 'CCD_BUF_TEST_STAT', minp2, maxp2
  self->record, 'icu_status_parameters', 'ET_STAT', minp3, maxp3
  self->record, 'icu_status_parameters', 'CMD_BUF_STAT', minp4, maxp4
  self->record, 'icu_status_parameters', 'XRT_FF_STAT', minp5, maxp5
  self->record, 'icu_status_parameters', 'EIS_FF_STAT', minp6, maxp6
  self->record, 'icu_status_parameters', 'HM_MON_STAT', minp7, maxp7
  self->record, 'icu_status_parameters', 'AEC_STAT', minp8, maxp8
  self->record, 'icu_status_parameters', 'MEM_DMP_STAT', minp9, maxp9
  self->record, 'icu_status_parameters', 'SEQ_STAT', minp10, maxp10
  self->record, 'icu_status_parameters', 'MODE_EN_STAT', minp11, maxp11
  self->record, 'icu_status_parameters', 'XRT_FF_REC', minp12, maxp12
  self->record, 'icu_status_parameters', 'XRT_X_COR', minp13, maxp13
  self->record, 'icu_status_parameters', 'XRT_Y_COR', minp14, maxp14
  self->record, 'icu_status_parameters', 'MD_BUF_STAT', minp15, maxp15
  self->record, 'icu_status_parameters', 'ICU_VF', minp16, maxp16
  self->record, 'icu_status_parameters', 'PSU_VF', minp17, maxp17
  self->record, 'icu_status_parameters', 'CAM_VF', minp18, maxp18
  self->record, 'icu_status_parameters', 'MHC_VF', minp19, maxp19
  self->record, 'icu_status_parameters', 'ASRC_STAT', minp20, maxp20
  self->record, 'icu_status_parameters', 'MHC_LOAD_STAT', minp21, maxp21
  self->record, 'icu_status_parameters', 'HC_STAT', minp22, maxp22
  self->record, 'icu_status_parameters', 'EEPROM_STAT1', minp23, maxp23
  self->record, 'icu_status_parameters', 'EEPROM_STAT2', minp24, maxp24
  self->record, 'icu_status_parameters', 'EEPROM_COPY_REQ_STAT', minp25, maxp25
  self->record, 'icu_status_parameters', 'EEPROM_COPY_PROG_STAT', minp26, maxp26
  self->record, 'icu_status_parameters', 'CAM_MHC_PWR_ON', minp27, maxp27

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_status_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],yrange=[-1,6], $
         xstyle=2,pstyle=4,title='EIS MODE',ytitle='Mode',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CCD BUF TEST STAT',ytitle='None',charsize=cs,/ynozero
  
;    utplot,x,p2,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      title='CCD BUF TEST ERR',ytitle='None',charsize=cs,/ynozero
  
;    utplot,x,p3,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      title='CCD BUF TEST WR ERR',ytitle='None',charsize=cs,/ynozero
  
;    utplot,x,p4,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      title='CCD BUF TEST RD ERR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4, $
         title='ET STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CMD BUF STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p7,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='XRT FF STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p8,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EIS FF STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p9,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM MON STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p10,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='AEC STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p11,base_time,timerange=[base_time,end_time],yrange=[0,4], $
         xstyle=2,pstyle=4,title='MEM DMP STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p12,base_time,timerange=[base_time,end_time],yrange=[0,4], $
         xstyle=2,pstyle=4,title='SEQ STAT',ytitle='None',charsize=cs,/ynozero

  utplot,x,p13,base_time,timerange=[base_time,end_time],yrange=[0,4], $
         xstyle=2,pstyle=4,title='MODE EN STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p14,base_time,timerange=[base_time,end_time],yrange=[-1,2], $
         xstyle=2,pstyle=4,title='XRT FF REC',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p15,base_time,timerange=[base_time,end_time],yrange=[-1,256], $
         xstyle=2,pstyle=4,title='XRT X COR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p16,base_time,timerange=[base_time,end_time],yrange=[-1,256], $
         xstyle=2,pstyle=4,title='XRT Y COR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p17,base_time,timerange=[base_time,end_time],yrange=[-1,6], $
         xstyle=2,pstyle=4,title='MD BUF STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p18,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4,title='ICU VF',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p19,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4,title='PSU VF',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p20,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4,title='CAM VF',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p21,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4,title='MHC VF',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p22,base_time,timerange=[base_time,end_time],yrange=[0,3], $
         xstyle=2,pstyle=4,title='ASRC STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p23,base_time,timerange=[base_time,end_time],yrange=[0,4], $
         xstyle=2,pstyle=4,title='MHC LOAD STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p24,base_time,timerange=[base_time,end_time],yrange=[0,4], $
         xstyle=2,pstyle=4,title='HC STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p25,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EEPROM STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p26,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EEPROM STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p27,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EEPROM COPY REQ STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p28,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EEPROM COPY PROG STAT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p29,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CAM_MHC_PWR_ON',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_psu_status_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_psu_status_parameters'
  
  p0  = eis_get_daily_data(files,'PSU_MARK',            1,  6, maxp1, minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'PSU_CCDB_HTR_EN',     2,  6, maxp2, minp2)
  p2  = eis_get_daily_data(files,'PSU_CCDA_HTR_EN',     3,  6, maxp3, minp3)
  p3  = eis_get_daily_data(files,'PSU_CCDB_BHTR_STAT',  4,  6, maxp4, minp4)
  p4  = eis_get_daily_data(files,'PSU_CCDA_BHTR_STAT',  5,  6, maxp5, minp5)
  p5  = eis_get_daily_data(files,'PSU_MHC_HTR_P28V',    6,  6, maxp6, minp6)
  p6  = eis_get_daily_data(files,'PSU_MHC_MECH_P28V',   7,  6, maxp7, minp7)
  p7  = eis_get_daily_data(files,'PSU_MHC_ELEC_P28V',   8,  6, maxp8, minp8)
  p8  = eis_get_daily_data(files,'PSU_MHC_MHTR',        9,  6, maxp9, minp9)
  p9  = eis_get_daily_data(files,'PSU_CAM_MHTR',       10,  6, maxp10, minp10)
  p10 = eis_get_daily_data(files,'PSU_CAM_P39V',       11,  6, maxp11, minp11)
  p11 = eis_get_daily_data(files,'PSU_CAM_N8V',        12,  6, maxp12, minp12)
  p12 = eis_get_daily_data(files,'PSU_CAM_P7V',        13,  6, maxp13, minp13)
  p13 = eis_get_daily_data(files,'PSU_CAM_P8V',        14,  6, maxp14, minp14)
  p14 = eis_get_daily_data(files,'PSU_CAM_P13V',       15,  6, maxp15, minp15)

  self->record, 'icu_psu_status_parameters', 'PSU_MARK',           minp1, maxp1
  self->record, 'icu_psu_status_parameters', 'PSU_CCDB_HTR_EN',    minp2, maxp2
  self->record, 'icu_psu_status_parameters', 'PSU_CCDA_HTR_EN',    minp3, maxp3
  self->record, 'icu_psu_status_parameters', 'PSU_CCDB_BHTR_STAT', minp4, maxp4
  self->record, 'icu_psu_status_parameters', 'PSU_CCDA_BHTR_STAT', minp5, maxp5
  self->record, 'icu_psu_status_parameters', 'PSU_MHC_HTR_P28V',   minp6, maxp6
  self->record, 'icu_psu_status_parameters', 'PSU_MHC_MECH_P28V',  minp7, maxp7
  self->record, 'icu_psu_status_parameters', 'PSU_MHC_ELEC_P28V',  minp8, maxp8
  self->record, 'icu_psu_status_parameters', 'PSU_MHC_MHTR',       minp9, maxp9
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_MHTR',       minp10, maxp10
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_P39V',       minp11, maxp11
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_N8V',        minp12, maxp12
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_P7V',        minp13, maxp13
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_P8V',        minp14, maxp14
  self->record, 'icu_psu_status_parameters', 'PSU_CAM_P13V',       minp15, maxp15

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_psu_status_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],yrange=[-1,2], $
         xstyle=2,pstyle=4, $
         title='PSU MARK',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CCDB HTR EN',ytitle='None',charsize=cs
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CCDA HTR EN',ytitle='None',charsize=cs
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CCDB BHTR STAT',ytitle='None',charsize=cs
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CCDA BHTR STAT',ytitle='None',charsize=cs
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU MHC HTR P28V',ytitle='None',charsize=cs
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU MHC MECH P28V',ytitle='None',charsize=cs
  
  utplot,x,p7,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU MHC ELEC P28V',ytitle='None',charsize=cs
  
  utplot,x,p8,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU MHC MHTR',ytitle='None',charsize=cs
  
  utplot,x,p9,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM MHTR',ytitle='None',charsize=cs
  
  utplot,x,p10,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM P39V',ytitle='None',charsize=cs
  
  utplot,x,p11,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM N8V',ytitle='None',charsize=cs
  
  utplot,x,p12,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM P7V',ytitle='None',charsize=cs
  
  utplot,x,p13,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM P8V',ytitle='None',charsize=cs
  
  utplot,x,p14,base_time,timerange=[base_time,end_time],yrange=[-1,2],xstyle=2,pstyle=4, $
         title='PSU CAM P13V',ytitle='None',charsize=cs
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_hm_status_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_hm_status_parameters'
  
;;;  p0  = eis_get_daily_data(files,'HM_OOL_ALERT', 1,  7, maxp1, minp1, base_time, end_time)
  p0  = eis_get_daily_data(files,'HM_ALERT_OOL', 1,  7, maxp1, minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'HM_PSU_TO',    2,  7, maxp2, minp2)
  p2  = eis_get_daily_data(files,'HM_CAM_TO',    3,  7, maxp3, minp3)
  p3  = eis_get_daily_data(files,'HM_MHC_TO',    4,  7, maxp4, minp4)
  p4  = eis_get_daily_data(files,'HM_PSU_OOL',   5,  7, maxp5, minp5)
  p5  = eis_get_daily_data(files,'HM_CAM_OOL',   6,  7, maxp6, minp6)
  p6  = eis_get_daily_data(files,'HM_MHC_OOL',   7,  7, maxp7, minp7)
  p7  = eis_get_daily_data(files,'HM_PARM_ID',   8,  7, maxp8, minp8)

  self->record, 'icu_hm_status_parameters', 'HM_ALERT_OOL', minp1, maxp1
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp2, maxp2
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp3, maxp3
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp4, maxp4
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp5, maxp5
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp6, maxp6
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp7, maxp7
  self->record, 'icu_hm_status_parameters', 'HM_PSU_TO',    minp8, maxp8

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_hm_status_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      yrange=[eis_convert_icu_current_p2p5v([minp1]),eis_convert_icu_current_p2p5v([maxp1])], $
         title='HM OOL ALERT',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM PSU TO',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM CAM TO',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM MHC TO',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM PSU OOL',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM CAM OOL',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM MHC OOL',ytitle='None',charsize=cs,/ynozero

  utplot,x,p7,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HM PARM ID',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_interface_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_interface_parameters'
  
  p0  = eis_get_daily_data(files,'CMD_IF_STAT1',  1,  8, maxp1,  minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'MD_IF_STAT1',   2,  8, maxp2,  minp2)
  p2  = eis_get_daily_data(files,'STAT_IF_STAT1', 3,  8, maxp3,  minp3)
  p3  = eis_get_daily_data(files,'WD_IF_STAT1',   4,  8, maxp4,  minp4)
  p4  = eis_get_daily_data(files,'CMD_IF_STAT2',  5,  8, maxp5,  minp5)
  p5  = eis_get_daily_data(files,'MD_IF_STAT2',   6,  8, maxp6,  minp6)
  p6  = eis_get_daily_data(files,'STAT_IF_STAT2', 7,  8, maxp7,  minp7)
  p7  = eis_get_daily_data(files,'WD_IF_STAT2',   8,  8, maxp8,  minp8)
  p8  = eis_get_daily_data(files,'MHC_422_STAT1', 9,  8, maxp9,  minp9)
  p9  = eis_get_daily_data(files,'ROE_IF_STAT1',  10, 8, maxp10, minp10)
  p10 = eis_get_daily_data(files,'ROE_IF_STAT2',  11, 8, maxp11, minp11)
  p11 = eis_get_daily_data(files,'HSL_IF_STAT1',  12, 8, maxp12, minp12)
  p12 = eis_get_daily_data(files,'HSL_IF_STAT2',  13, 8, maxp13, minp13)
  p13 = eis_get_daily_data(files,'MHC_422_STAT2', 14, 8, maxp14, minp14)

  self->record, 'icu_interface_parameters', 'CMD_IF_STAT1',  minp1,  maxp1
  self->record, 'icu_interface_parameters', 'MD_IF_STAT1',   minp2,  maxp2
  self->record, 'icu_interface_parameters', 'STAT_IF_STAT1', minp3,  maxp3
  self->record, 'icu_interface_parameters', 'WD_IF_STAT1',   minp4,  maxp4
  self->record, 'icu_interface_parameters', 'CMD_IF_STAT2',  minp5,  maxp5
  self->record, 'icu_interface_parameters', 'MD_IF_STAT2',   minp6,  maxp6
  self->record, 'icu_interface_parameters', 'STAT_IF_STAT2', minp7,  maxp7
  self->record, 'icu_interface_parameters', 'WD_IF_STAT2',   minp8,  maxp8
  self->record, 'icu_interface_parameters', 'MHC_422_STAT1', minp9,  maxp9
  self->record, 'icu_interface_parameters', 'ROE_IF_STAT1',  minp10, maxp10
  self->record, 'icu_interface_parameters', 'ROE_IF_STAT2',  minp11, maxp11
  self->record, 'icu_interface_parameters', 'HSL_IF_STAT1',  minp12, maxp12
  self->record, 'icu_interface_parameters', 'HSL_IF_STAT2',  minp13, maxp13
  self->record, 'icu_interface_parameters', 'MHC_422_STAT2', minp14, maxp14

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_interface_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      yrange=[eis_convert_icu_current_p2p5v([minp1]),eis_convert_icu_current_p2p5v([maxp1])], $
         title='CMD IF STAT1',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MD IF STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='STAT IF STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='WD IF STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CMD IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MD IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='STAT IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p7,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='WD IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p8,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MHC 422 STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p9,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='ROE IF STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p10,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='ROE IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p11,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HSL IF STAT1',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p12,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HSL IF STAT2',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p13,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MHC 422 STAT2',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_error_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_error_parameters'
  
  p0  = eis_get_daily_data(files,'TC_FAILED_EC',      1,  9, maxp1,  minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'CMD_IF_ERROR',      2,  9, maxp2,  minp2)
  p2  = eis_get_daily_data(files,'PSU_STAT_ERROR',    3,  9, maxp3,  minp3)
  p3  = eis_get_daily_data(files,'TC_FAILED_CMD_ID',  4,  9, maxp4,  minp4)
  p4  = eis_get_daily_data(files,'ICU_ERROR_F',       5,  9, maxp5,  minp5)
  p5  = eis_get_daily_data(files,'XRT_ERROR',         6,  9, maxp6,  minp6)
  p6  = eis_get_daily_data(files,'HC_DUTY_ERROR',     7,  9, maxp7,  minp7)
  p7  = eis_get_daily_data(files,'HC_PSU_TO',         8,  9, maxp8,  minp8)
  p8  = eis_get_daily_data(files,'MDP_LL_ERROR',      9,  9, maxp9,  minp9)
  p9  = eis_get_daily_data(files,'MHC_CMD_H',         10, 9, maxp10, minp10)
  p10 = eis_get_daily_data(files,'FT_ERROR',          11, 9, maxp11, minp11)
  p11 = eis_get_daily_data(files,'AEC_WIN_ERROR',     12, 9, maxp12, minp12)
  p12 = eis_get_daily_data(files,'AEC_PARMS_ERROR',   13, 9, maxp13, minp13)
  p13 = eis_get_daily_data(files,'AEC_TIME_ERROR',    14, 9, maxp14, minp14)
  p14 = eis_get_daily_data(files,'CAM_IF_ERROR',      15, 9, maxp15, minp15)
  p15 = eis_get_daily_data(files,'SEQ_ABORT_CODE',    16, 9, maxp16, minp16)
  p16 = eis_get_daily_data(files,'CMD_ID_FAILED_INT', 17, 9, maxp17, minp17)
  p17 = eis_get_daily_data(files,'MHC_IF_ERROR',      18, 9, maxp18, minp18)
  p18 = eis_get_daily_data(files,'EEPROM_ERROR',      19, 9, maxp19, minp19)
  p19 = eis_get_daily_data(files,'ET_ERROR',          20, 9, maxp20, minp20)
  p20 = eis_get_daily_data(files,'TC_FAILED_PKTC',    21, 9, maxp21, minp21)

  self->record, 'icu_error_parameters', 'TC_FAILED_EC',      minp1,  maxp1
  self->record, 'icu_error_parameters', 'CMD_IF_ERROR',      minp2,  maxp2
  self->record, 'icu_error_parameters', 'PSU_STAT_ERROR',    minp3,  maxp3
  self->record, 'icu_error_parameters', 'TC_FAILED_CMD_ID',  minp4,  maxp4
  self->record, 'icu_error_parameters', 'ICU_ERROR_F',       minp5,  maxp5
  self->record, 'icu_error_parameters', 'XRT_ERROR',         minp6,  maxp6
  self->record, 'icu_error_parameters', 'HC_DUTY_ERROR',     minp7,  maxp7
  self->record, 'icu_error_parameters', 'HC_PSU_TO',         minp8,  maxp8
  self->record, 'icu_error_parameters', 'MDP_LL_ERROR',      minp9,  maxp9
  self->record, 'icu_error_parameters', 'MHC_CMD_H',         minp10, maxp10
  self->record, 'icu_error_parameters', 'FT_ERROR',          minp11, maxp11
  self->record, 'icu_error_parameters', 'AEC_WIN_ERROR',     minp12, maxp12
  self->record, 'icu_error_parameters', 'AEC_PARMS_ERROR',   minp13, maxp13
  self->record, 'icu_error_parameters', 'AEC_TIME_ERROR',    minp14, maxp14
  self->record, 'icu_error_parameters', 'CAM_IF_ERROR',      minp15, maxp15
  self->record, 'icu_error_parameters', 'SEQ_ABORT_CODE',    minp16, maxp16
  self->record, 'icu_error_parameters', 'CMD_ID_FAILED_INT', minp17, maxp17
  self->record, 'icu_error_parameters', 'MHC_IF_ERROR',      minp18, maxp18
  self->record, 'icu_error_parameters', 'EEPROM_ERROR',      minp19, maxp19
  self->record, 'icu_error_parameters', 'ET_ERROR',          minp20, maxp20
  self->record, 'icu_error_parameters', 'TC_FAILED_PKTC',    minp21, maxp21

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_error_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      yrange=[eis_convert_icu_current_p2p5v([minp1]),eis_convert_icu_current_p2p5v([maxp1])], $
         title='TC_FAILED_EC',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CMD_IF_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='PSU_STAT_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='TC_FAILED_CMD_ID',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='ICU_ERROR_F',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='XRT_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p6,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HC_DUTY_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p7,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='HC_PSU_TO',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p8,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MDP_LL_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p9,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MHC_CMD_H',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p10,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='FT_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p11,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='AEC_WIN_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p12,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='AEC_PARMS_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p13,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='AEC_TIME_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p14,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CAM_IF_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p15,base_time,timerange=[base_time,end_time],yrange=[-1,16],xstyle=2,pstyle=4, $
         title='SEQ_ABORT_CODE',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p16,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='CMD_ID_FAILED_INT',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p17,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='MHC_IF_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p18,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='EEPROM_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p19,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='ET_ERROR',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p20,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='TC_FAILED_PKTC',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_counter_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_counter_parameters'
  
  p0  = eis_get_daily_data(files,'MDP_TIME',       1,  10, maxp0, minp0, base_time, end_time)
  p1  = eis_get_daily_data(files,'STATUS_PC',      2,  10, maxp1, minp1)
  p2  = eis_get_daily_data(files,'TC_REC_PKTC',    3,  10, maxp2, minp2)
  p3  = eis_get_daily_data(files,'RASTER_RUN_REM', 4,  10, maxp3, minp3)
  p4  = eis_get_daily_data(files,'SEQ_RUN_REM',    5,  10, maxp4, minp4)
  p5  = eis_get_daily_data(files,'EXP_NUM',        6,  10, maxp5, minp5)

  self->record, 'icu_counter_parameters', 'MDP_TIME',       minp0, maxp0
  self->record, 'icu_counter_parameters', 'STATUS_PC',      minp1, maxp1
  self->record, 'icu_counter_parameters', 'TC_REC_PKTC',    minp2, maxp2
  self->record, 'icu_counter_parameters', 'RASTER_RUN_REM', minp3, maxp3
  self->record, 'icu_counter_parameters', 'SEQ_RUN_REM',    minp4, maxp4
  self->record, 'icu_counter_parameters', 'EXP_NUM',        minp5, maxp5

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_counter_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],yrange=[minp0-1,maxp0+1],xstyle=2,pstyle=4, $
         title='MDP_TIME',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],yrange=[minp1-1,maxp1+1],xstyle=2,pstyle=4, $
         title='STATUS_PC',ytitle='None',charsize=cs
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],yrange=[minp2-1,maxp2+1],xstyle=2,pstyle=4, $
         title='TC_REC_PKTC',ytitle='None',charsize=cs
  
  utplot,x,p3,base_time,timerange=[base_time,end_time],yrange=[minp3-1,maxp3+1],xstyle=2,pstyle=4, $
         title='RASTER_RUN_REM',ytitle='None',charsize=cs
  
  utplot,x,p4,base_time,timerange=[base_time,end_time],yrange=[minp4-1,maxp4+1],xstyle=2,pstyle=4, $
         title='SEQ_RUN_REM',ytitle='None',charsize=cs
  
  utplot,x,p5,base_time,timerange=[base_time,end_time],yrange=[minp5-1,maxp5+1],xstyle=2,pstyle=4, $
         title='EXP_NUM',ytitle='None',charsize=cs
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_science_status_parameters, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_science_status_parameters'
  
  p0  = eis_get_daily_data(files,'SEQ_I', 1,  11, maxp0, minp0, base_time, end_time)
  p1  = eis_get_daily_data(files,'SEQ_P', 2,  11, maxp1, minp1)
  p2  = eis_get_daily_data(files,'LL_I',  3,  11, maxp2, minp2)

  self->record, 'icu_science_status_parameters', 'SEQ_I', minp0, maxp0
  self->record, 'icu_science_status_parameters', 'SEQ_P', minp1, maxp1
  self->record, 'icu_science_status_parameters', 'LL_I',  minp2, maxp2

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_science_status_parameters.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],yrange=[minp0-1,maxp0+1],xstyle=2,pstyle=4, $
         title='SEQ_I',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],yrange=[minp1-1,maxp1+1],xstyle=2,pstyle=4, $
         title='SEQ_P',ytitle='None',charsize=cs,/ynozero
  
  utplot,x,p2,base_time,timerange=[base_time,end_time],yrange=[minp2-1,maxp2+1],xstyle=2,pstyle=4, $
         title='LL_I',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot_icu_spacecraft, files, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot_icu_spacecraft'
  
  p0  = eis_get_daily_data(files,'TIME',        1,  12, maxp1, minp1, base_time, end_time)
  p1  = eis_get_daily_data(files,'SEQ_COUNTER', 2,  12, maxp2, minp2)

  self->record, 'icu_spacecraft', 'TIME',        minp1, maxp1
  self->record, 'icu_spacecraft', 'SEQ_COUNTER', minp2, maxp2

  x = lindgen(n_elements(p0))*2
  
  cs=1.6
  
  set_plot,'ps'
  device,xoff=2.5,yoff=6,xs=16,ys=18,file=output+'/icu_spacecraft.ps'
  !p.multi=[0,1,3]
  
  utplot,x,p0,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
;      yrange=[eis_convert_icu_current_p2p5v([minp1]),eis_convert_icu_current_p2p5v([maxp1])], $
         title='TIME',ytitle='None',charsize=cs
  
  utplot,x,p1,base_time,timerange=[base_time,end_time],xstyle=2,pstyle=4, $
         title='SEQ_COUNTER',ytitle='None',charsize=cs,/ynozero
  
  device,/close
  set_plot,'X'
  !p.multi=0
  
end

pro eis_status_sts1_data_dumper::plot, dir, output, end_time
  self->trace, 'eis_status_sts1_data_dumper::plot'
  
  files = findfile(dir + '/eis_sts1_*fits', count=count)
  if count eq 0 then begin
     print, 'eis_status_sts1_data_dumper::plot : No files'
     return
  endif
  
  self->plot_icu_voltages,                  files, output, end_time
  self->plot_icu_currents,                  files, output, end_time
  self->plot_icu_temperatures,              files, output, end_time
  self->plot_icu_misc_parameters,           files, output, end_time
  self->plot_icu_status_parameters,         files, output, end_time
  self->plot_icu_psu_status_parameters,     files, output, end_time
  self->plot_icu_hm_status_parameters,      files, output, end_time
  self->plot_icu_interface_parameters,      files, output, end_time
  self->plot_icu_error_parameters,          files, output, end_time
  self->plot_icu_counter_parameters,        files, output, end_time
  self->plot_icu_science_status_parameters, files, output, end_time
  self->plot_icu_spacecraft,                files, output, end_time

  self->debug, self.parameters

end
